Application developer guide
===========================

Using Weblate is a process that brings your users closer to you, by bringing you closer to your translators.
It is up to you to decide how many of its features you want to make use of.

.. toctree::

    starting
    gettext
    sphinx
    html
    alerts
    community
    translations
    review
    share
    reporting
